﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using System.ComponentModel;

namespace XamGridEditorTest
{
    public partial class MainWindow: Window, INotifyPropertyChanged
    {
        private ObservableCollection<Person> _People;
        public ObservableCollection<Person> People
        {
            get { return _People; }
            set
            {
                if (_People != value)
                {
                    _People = value;
                    RaisePropertyChanged("People");
                }
            }
        }

        private ObservableCollection<Trade> _Trades;
        public ObservableCollection<Trade> Trades
        {
            get { return _Trades; }
            set
            {
                if (_Trades != value)
                {
                    _Trades = value;
                    RaisePropertyChanged("Trades");
                }
            }
        }

        public MainWindow()
        {
            InitializeComponent();
            DataContext = this;
            People = new ObservableCollection<Person>();

            for (int i = 0; i < 100000; i++)
                People.Add(new Person { ID = i, Name = Guid.NewGuid().ToString() });

            Trades = new ObservableCollection<Trade>();
            Trades.Add(new Trade { ACCT_NO = 100, ACCT_Name = "Smith", CUSIP = "WXYZ", QTY = 100 });
            Trades.Add(new Trade { ACCT_NO = 200, ACCT_Name = "Jones", CUSIP = "BLAH", QTY = 500 });
            Trades.Add(new Trade { ACCT_NO = 300, ACCT_Name = "Johnson", CUSIP = "ABCD", QTY = 900 });
        }


        public event PropertyChangedEventHandler PropertyChanged;

        protected void RaisePropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }

        private void SelectorTextBox_SelectionChanged(KeyValuePair<string, string> SelectedItem)
        {
            Trade t = (Trade)grid.ActiveDataItem;
            t.ACCT_NO = Convert.ToInt32(SelectedItem.Key);
            t.ACCT_Name = SelectedItem.Value;
        }
    }

    public class Trade : INotifyPropertyChanged
    {
        private int _ACCT_NO;
        public int ACCT_NO
        {
            get { return _ACCT_NO; }
            set
            {
                if (_ACCT_NO != value)
                {
                    _ACCT_NO = value;
                    RaisePropertyChanged("ACCT_NO");
                }
            }
        }

        private string _ACCT_Name;
        public string ACCT_Name
        {
            get { return _ACCT_Name; }
            set
            {
                if (_ACCT_Name != value)
                {
                    _ACCT_Name = value;
                    RaisePropertyChanged("ACCT_Name");
                }
            }
        }

        private decimal _QTY;
        public decimal QTY
        {
            get { return _QTY; }
            set
            {
                if (_QTY != value)
                {
                    _QTY = value;
                    RaisePropertyChanged("QTY");
                }
            }
        }

        private string _CUSIP;
        public string CUSIP
        {
            get { return _CUSIP; }
            set
            {
                if (_CUSIP != value)
                {
                    _CUSIP = value;
                    RaisePropertyChanged("CUSIP");
                }
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;

        protected void RaisePropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }
    }


    public class Person
    {
        public int ID { get; set; }
        public string Name { get; set; }
    }
}
